﻿// <copyright file="SearchResult.cs" company="Mek">
// DC Search by Mek (www.mekweb.eu), all rights reserved.
// </copyright>
// <author>Mek</author>

namespace DcLibrary
{
    using System.Globalization;

    /// <summary>
    /// Class representing search result
    /// </summary>
    public class SearchResult
    {
        /// <summary>
        /// Gets or sets hub address
        /// </summary>
        public string HubAddress { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether result is a folder
        /// </summary>
        public bool IsFolder { get; set; }

        /// <summary>
        /// Gets or sets file/folder name (without path)
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Gets or sets nickname of the user sharing result file/folder
        /// </summary>
        public string Nick { get; set; }

        /// <summary>
        /// Gets or sets path to file/folder in user's share
        /// </summary>
        public string Path { get; set; }

        /// <summary>
        /// Gets or sets file size (zero for folders)
        /// </summary>
        public long Size { get; set; }

        /// <summary>
        /// Gets or sets slots of user (number of free/all slots, e.g. 2/5)
        /// </summary>
        public string Slots { get; set; }

        /// <summary>
        /// Gets or sets result TTH (null for folders)
        /// </summary>
        public string TTH { get; set; }

        /// <summary>
        /// Gets size formatted with size unit
        /// </summary>
        public string SizeFormatted
        {
            get
            {
                string result = string.Empty;

                if (!this.IsFolder)
                {
                    if (this.Size < 1024)
                    {
                        result = this.Size.ToString(CultureInfo.CurrentCulture) + " B";
                    }
                    else if (this.Size >= 1024 && this.Size < 1024 * 1024)
                    {
                        result = (this.Size / 1024d).ToString("F2", CultureInfo.CurrentCulture) + " KiB";
                    }
                    else if (this.Size >= 1024 * 1024 && this.Size < 1024 * 1024 * 1024)
                    {
                        result = (this.Size / (1024 * 1024d)).ToString("F2", CultureInfo.CurrentCulture) + " MiB";
                    }
                    else if (this.Size >= 1024 * 1024 * 1024)
                    {
                        result = (this.Size / (1024 * 1024 * 1024d)).ToString("F2", CultureInfo.CurrentCulture) + " GiB";
                    }
                }

                return result;
            }
        }
    }
}
