﻿// <copyright file="StringUtility.cs" company="Mek">
// DC Search by Mek (www.mekweb.eu), all rights reserved.
// </copyright>
// <author>Mek</author>

namespace DcLibrary
{
    using System;
    using System.Text;
    using System.Text.RegularExpressions;

    /// <summary>
    /// Contains helper methods for manipulating strings
    /// </summary>
    public static class StringUtility
    {
        /// <summary>
        /// Returns true if input string is an IP address in decimal IPv4 format
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        public static bool IsIPAddress(string input)
        {
            return Regex.IsMatch(input, @"^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$");
        }

        /// <summary>
        /// Sanitizes string for use in DC commands
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        public static string SanitizeSearchString(string input)
        {
            return input.Replace("|", string.Empty).Replace("$", "&#36;").Replace(' ', '$');
        }

        /// <summary>
        /// Generates response for $Lock DirectConnect command
        /// http://wiki.gusari.org/index.php?title=LockToKey%28%29#C.23
        /// </summary>
        /// <param name="lockCommand">Full command, including leading $Lock</param>
        /// <returns></returns>
        internal static string Lock2Key(string lockCommand)
        {
            lockCommand = lockCommand.Replace("$Lock ", string.Empty);
            int pos = lockCommand.IndexOf(" Pk=", 1);

            if (pos > 0)
            {
                lockCommand = lockCommand.Substring(0, pos);
            }

            int[] arrChar = new int[lockCommand.Length + 1];
            int[] arrRet = new int[lockCommand.Length + 1];
            arrChar[1] = lockCommand[0];

            for (int i = 2; i < lockCommand.Length + 1; i++)
            {
                arrChar[i] = lockCommand[i - 1];
                arrRet[i] = arrChar[i] ^ arrChar[i - 1];
            }

            arrRet[1] = arrChar[1] ^ arrChar[lockCommand.Length] ^ arrChar[lockCommand.Length - 1] ^ 5;
            string strKey = string.Empty;

            for (int n = 1; n < lockCommand.Length + 1; n++)
            {
                arrRet[n] = ((arrRet[n] * 16) & 240) | ((arrRet[n] / 16) & 15);
                int j = arrRet[n];

                switch (j)
                {
                    case 0:
                    case 5:
                    case 36:
                    case 96:
                    case 124:
                    case 126:
                        strKey += "/%DCN"
                             + ((string)("00" + j.ToString())).Substring(j.ToString().Length - 1)
                             + "%/";
                        break;
                    default:
                        strKey += Chr(Convert.ToByte((char)j));
                        break;
                }
            }

            return strKey;
        }

        /// <summary>
        /// Returns a character with specified code
        /// </summary>
        /// <param name="src"></param>
        /// <returns></returns>
        private static char Chr(byte src)
        {
            return Encoding.Default.GetChars(new byte[] { src })[0];
        }
    }
}
