﻿// <copyright file="IPAddressGetter.cs" company="Mek">
// DC Search by Mek (www.mekweb.eu), all rights reserved.
// </copyright>
// <author>Mek</author>

namespace DcSearch
{
    using System;
    using System.Net;
    using DcLibrary;

    /// <summary>
    /// Class for getting current Internet IP address
    /// </summary>
    public static class IPAddressGetter
    {
        /// <summary>
        /// Starts getting IP address asynchronously. Invokes specified callback when complete.
        /// </summary>
        /// <param name="callback"></param>
        public static void StartGetIPAddress(Action<string> callback)
        {
            if (callback != null)
            {
                WebClient webClient = new WebClient()
                {
                    Proxy = null
                };

                webClient.DownloadStringAsync(new Uri("http://mekweb.eu/ip.php"));

                DownloadStringCompletedEventHandler completedHandler = null;

                completedHandler = (s, e) =>
                {
                    if (!string.IsNullOrWhiteSpace(e.Result))
                    {
                        string result = string.Empty;
                        var endIndex = e.Result.IndexOf('<');

                        if (endIndex != -1)
                        {
                            string subString = e.Result.Substring(0, endIndex);
                            if (StringUtility.IsIPAddress(subString))
                            {
                                result = subString;
                            }
                        }

                        callback(result);
                    }
                };

                webClient.DownloadStringCompleted += completedHandler;
            }
        }
    }
}
